=============================================
overgang -- Transition probability estimation
=============================================

The overgang package includes the Duration Method to estimate 
the transitions probability matrix (stochastic matrix).
A common application are Credit Rating migrations.

